=======================================================
``psyclone.psyir.transformations.transformation_error``
=======================================================

.. automodule:: psyclone.psyir.transformations.transformation_error

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.transformation_error
